@@ -178,7 +178,7 @@ def export_reference_tables(ea, include_lessons):
     if not users or not custom_fields or not group_users:
         users, custom_fields, group_users = ea.discover_users()
         df_users = to_dataframe(users)
-        df_users.drop(columns=["customFields", "userGroups"], inplace=True)
+        df_users = df_users.drop(columns=["customFields", "userGroups"])
         export_to_csv(df_users, "users")
         setup_sqlite("users", users_sql, convert_to_records(df_users), drop=True)
 
@@ -199,8 +199,6 @@ def export_reference_tables(ea, include_lessons):
             drop=True,
         )
 
-        users = df_to_dictionary(df_users)
-
     # Courses
     courses, course_cols, last_export = database_or_export(cur, "courses")
     if not courses:
